==> haskell-hls-floskell-plugin-1.0.0.1-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-floskell-plugin
version:              1.0.0.1
visibility:           public
id:                   hls-floskell-plugin-1.0.0.1-AcBWHxaLOd1Iqj72GH74qY
key:                  hls-floskell-plugin-1.0.0.1-AcBWHxaLOd1Iqj72GH74qY
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  76886682107263bf82891c9f0a82ab47
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hls-floskell-plugin-1.0.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hls-floskell-plugin-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/hls-floskell-plugin-1.0.0.1

hs-libraries:         HShls-floskell-plugin-1.0.0.1-AcBWHxaLOd1Iqj72GH74qY
depends:
    base-4.15.1.0 floskell-0.10.5-5lSF9Mnsv8P9oJGqIm2aSH
    ghcide-1.4.1.0-K0BdF4WkVuD6nRoaHTQxYA
    hls-plugin-api-1.2.0.0-BWhCmgIlQ8Q5WDRCsyDAP9
    lsp-types-1.3.0.1-9eUKI0stArTBzwGJrWL4Yy text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-floskell-plugin-1.0.0.1-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-floskell-plugin
version:              1.0.0.1
visibility:           public
id:                   hls-floskell-plugin-1.0.0.1-BPeHlDfODtDHwz79XmHQX6
key:                  hls-floskell-plugin-1.0.0.1-BPeHlDfODtDHwz79XmHQX6
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  380d86d38605b53e30f2794610bc24ec
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hls-floskell-plugin-1.0.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hls-floskell-plugin-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/hls-floskell-plugin-1.0.0.1

hs-libraries:         HShls-floskell-plugin-1.0.0.1-BPeHlDfODtDHwz79XmHQX6
depends:
    base-4.15.1.0 floskell-0.10.5-EP62aPEpyT97MIQZHI1dcN
    ghcide-1.4.1.0-8fpMWGL53X2E402dRfUyyj
    hls-plugin-api-1.2.0.0-2qwOODfUkJcKbgKNdSpiH6
    lsp-types-1.3.0.1-9hZFyjbTCKl3EXv0C3D2aW text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
